<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Processor;

use Dedi\SyliusImportExportPlugin\Exporter\ExporterInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Contracts\Translation\TranslatorInterface;

class ExportProcessor implements ExportProcessorInterface
{
    private RequestStack $requestStack;

    private TranslatorInterface $translator;

    public function __construct(RequestStack $requestStack, TranslatorInterface $translator)
    {
        $this->requestStack = $requestStack;
        $this->translator = $translator;
    }

    public function process(ExporterInterface $exporter): Response
    {
        $currentRequest = $this->requestStack->getCurrentRequest();
        $criteria = $currentRequest !== null ? $currentRequest->get('criteria', []) : [];

        $data = $exporter
            ->getFormater()
            ->format(
                $exporter->getDataProvider()->getData($criteria)
            )
        ;

        $fjlename = $this->translator->trans($exporter->getFilename()) . '-' . (new \DateTime())->format('Y-m-d');

        return $exporter->getFormater()->output($data, $fjlename);
    }
}
